
---
# Relay 4 click

> Relay 4 Click is a compact add-on board with a general-purpose relay that any host MCU can control. This board features the J1031C3VDC, high-current single-pole double-throw (SPDT) signal relay from CIT Relay and Switch. Highly sensitive, the J1031C3VDC offers a low coil power consumption in a small, lightweight package with PC pin mounting. It comes with a dimension of 12.5x7.5x10 millimetre (LxWxH) and a 1C contact arrangement with a coil voltage of 3VDC, providing a switching voltage of 125VAC/60VDC maximum.

<p align="center">
  <img src="https://download.mikroe.com/images/click_for_ide/relay4_click.png" height=300px>
</p>

[click Product page](https://www.mikroe.com/relay-4-click)

---


#### Click library

- **Author**        : Stefan Filipovic
- **Date**          : Jan 2023.
- **Type**          : GPIO type


# Software Support

We provide a library for the Relay 4 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for Relay 4 Click driver.

#### Standard key functions :

- `relay4_cfg_setup` Config Object Initialization function.
```c
void relay4_cfg_setup ( relay4_cfg_t *cfg );
```

- `relay4_init` Initialization function.
```c
err_t relay4_init ( relay4_t *ctx, relay4_cfg_t *cfg );
```

#### Example key functions :

- `relay4_set_relay1_open` This function sets the relay 1 to normally open state by setting the RL1 pin to low logic level.
```c
void relay4_set_relay1_open ( relay4_t *ctx );
```

- `relay4_set_relay1_close` This function sets the relay 1 to normally close state by setting the RL1 pin to high logic level.
```c
void relay4_set_relay1_close ( relay4_t *ctx );
```

- `relay4_set_relay2_open` This function sets the relay 2 to normally open state by setting the RL2 pin to low logic level.
```c
void relay4_set_relay2_open ( relay4_t *ctx );
```

## Example Description

> This example demonstrates the use of Relay 4 click board by toggling the relays state.

**The demo application is composed of two sections :**

### Application Init

> Initializes the driver and logger.

```c

void application_init ( void )
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    relay4_cfg_t relay4_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    relay4_cfg_setup( &relay4_cfg );
    RELAY4_MAP_MIKROBUS( relay4_cfg, MIKROBUS_1 );
    if ( DIGITAL_OUT_UNSUPPORTED_PIN == relay4_init( &relay4, &relay4_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }
    
    log_info( &logger, " Application Task " );
}

```

### Application Task

> Switches the relays 1 and 2 state every 5 seconds and displays the state on the USB UART.

```c
void application_task ( void )
{
    relay4_set_relay1_open ( &relay4 );
    log_printf( &logger, " Relay 1 set to normally open state\r\n" );
    relay4_set_relay2_close ( &relay4 );
    log_printf( &logger, " Relay 2 set to normally close state\r\n\n" );
    Delay_ms ( 5000 );

    relay4_set_relay1_close ( &relay4 );
    log_printf( &logger, " Relay 1 set to normally close state\r\n" );
    relay4_set_relay2_open ( &relay4 );
    log_printf( &logger, " Relay 2 set to normally open state\r\n\n" );
    Delay_ms ( 5000 );
}
```

The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.Relay4

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
